@@ -1,5 +1,5 @@
 #
-# $Id: ftp.pm,v 1.23 1998/07/06 09:28:42 aas Exp $
+# $Id: ftp.pm,v 1.25 1998/11/19 21:45:01 aas Exp $
 
 # Implementation of the ftp protocol (RFC 959). We let the Net::FTP
 # package do all the dirty work.
@@ -112,18 +112,18 @@ sub request
     LWP::Debug::debug($ftp->message);
 
     # Get & fix the path
-    my @path =  $url->path_components;
+    my @path =  $url->path_segments;
     shift(@path);  # There will always be an empty first component
     pop(@path) while @path && $path[-1] eq '';  # remove empty tailing comps
     my $remote_file = pop(@path);
     $remote_file = '' unless defined $remote_file;
 
-    my $params = $url->params;
-    if (defined($params) && $params eq 'type=a') {
-	$ftp->ascii;
-    } else {
+#    my $params = $url->params;
+#    if (defined($params) && $params eq 'type=a') {
+#	$ftp->ascii;
+#    } else {
 	$ftp->binary;
-    }
+#    }
 
     for (@path) {
 	LWP::Debug::debug("CWD $_");
@@ -138,7 +138,7 @@ sub request
 	if (my $mod_time = $ftp->mdtm($remote_file)) {
 	    $response->last_modified($mod_time);
 	    if (my $ims = $request->if_modified_since) {
-		if ($mod_time > $ims) {
+		if ($mod_time <= $ims) {
 		    $response->code(&HTTP::Status::RC_NOT_MODIFIED);
 		    $response->message("Not modified");
 		    return $response;
